package com.gct.tools.etlcamelhuge;

import com.gct.tools.etlcamelhuge.routeconfig.CamelJDBCConfiguration;
import lombok.Data;
import org.json.JSONObject;
import org.junit.jupiter.api.Test;
import org.junit.runner.RunWith;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.boot.test.context.SpringBootTest;
import org.springframework.jdbc.core.JdbcTemplate;
import org.springframework.test.context.junit4.SpringRunner;

import javax.annotation.Resource;
import javax.sql.DataSource;
import java.lang.reflect.Array;
import java.lang.reflect.InvocationTargetException;
import java.time.LocalDate;
import java.time.format.DateTimeFormatter;
import java.util.*;
import java.util.concurrent.atomic.AtomicInteger;

@RunWith(SpringRunner.class)
@SpringBootTest(classes = EtlCamelHugeApplication.class)
class EtlCamelHugeApplicationTests {

    @Resource(name = "oracle")
    DataSource oracle;

    @Resource(name = "centralbase")
    DataSource centralbase;

    @Test
    public void testOracle() {
        JdbcTemplate template = new JdbcTemplate(oracle);
        String sql = String.format("select WELL_ID,well_common_name,org_id from " +
                "zy_dxgw.pc_dev_well_attr_info where well_purpose_name='采油井'");
        List<Map<String, Object>> maps = template.queryForList(sql);
        maps.get(0).forEach((k, v) -> {
            System.out.printf("k: %s, v: %s\n", k, v);
        });
    }

    @Test
    public void orgCreate() {
        JdbcTemplate oracleTemplate = new JdbcTemplate(oracle);
        final JdbcTemplate centralbaseTemplate = new JdbcTemplate(centralbase);
        String sql = String.format("select * from zy_dxgw.V_PC_ORGANIZATION_T where CANTON = '重油公司'");
        List<Map<String, Object>> results = oracleTemplate.queryForList(sql);

        Map<String, Map<String, Object>> parentObjMap = new HashMap<>();
        Map<String, Map<String, Object>> orgIdMap = new HashMap<>();
        AtomicInteger a = new AtomicInteger(1);
        results.forEach(rowMap -> {
            rowMap.put("org_id_map_int",a.getAndIncrement());
            orgIdMap.put(rowMap.get("ORG_ID").toString(), rowMap);
        });
        results.forEach(rowMap -> {
            parentObjMap.put(rowMap.get("ORG_ID").toString(), orgIdMap.get(rowMap.get("PARENT_ID")));
        });

        results.forEach(rowMap -> {
            Stack<String> orgPreStack = new Stack<>();
            Map<String, Object> parentObj = rowMap;

            while ((parentObj = parentObjMap.get(parentObj.get("ORG_ID").toString())) != null) {
                orgPreStack.push(parentObj.get("ORG_NAME").toString());
            }
            StringBuilder orgIdPre = new StringBuilder();
            while (!orgPreStack.isEmpty()) {
                orgIdPre.append(orgPreStack.pop()).append("@");
            }
            orgIdPre.append(rowMap.get("ORG_NAME"));
            String orgIdPreStr = orgIdPre.toString();
            rowMap.put("ORG_ID_PRE",orgIdPreStr);

            String sqlInsertOrg = String.format("insert into centralbase.cb_pc_organization(" +
                            "org_id,org_name,org_code,org_level,parent_id,org_id_pre) " +
                            "values('%s','%s','%s','%s','%s','%s')", rowMap.get("org_id_map_int"), rowMap.get("ORG_NAME"), rowMap.get("ORG_CODE"),
                    orgIdPreStr.split("@").length
                    , Objects.nonNull(orgIdMap.get(rowMap.get("PARENT_ID").toString()))?orgIdMap.get(rowMap.get("PARENT_ID").toString()).get("org_id_map_int"):"0"
                    , orgIdPreStr);
//            System.out.println(sqlInsertOrg);
            centralbaseTemplate.execute(sqlInsertOrg);   //excute finish, unused
        });

        if(a.get()>1)return;
        //excute wellsource
        sql = String.format("select WELL_ID,well_common_name,org_id from " +
                "zy_dxgw.pc_dev_well_attr_info where well_purpose_name='采油井'");
        results = oracleTemplate.queryForList(sql);
        results.forEach(rowMap -> {
            String wellId = rowMap.get("WELL_ID").toString();
            String wellCommonName = rowMap.get("WELL_COMMON_NAME").toString();
            String wellLegalName = rowMap.get("WELL_COMMON_NAME").toString();
            String orgId = rowMap.get("ORG_ID").toString();
            String orgIdMapInt = orgIdMap.get(orgId).get("org_id_map_int").toString();
            String stationId = orgIdMap.get(orgId).get("ORG_ID_PRE").toString();
           String  sqlInsertWellSource = String.format("insert into centralbase.cb_cd_well_source(well_id,well_common_name," +
                   "well_legal_name,org_id,station_id) values('%s','%s','%s','%s','%s')",
                   wellId, wellCommonName, wellLegalName, orgIdMapInt, stationId);
//            System.out.println(sqlInsertWellSource);
            centralbaseTemplate.execute(sqlInsertWellSource);
        });

    }

    @Test
    public void wellSourceCreate(){

    }
}
